@@ -51,7 +51,7 @@ class CertificateToPIVCardCommand::Private : public CardCommand::Private
     }
 public:
     explicit Private(CertificateToPIVCardCommand *qq, const std::string &slot, const std::string &serialno);
-    ~Private();
+    ~Private() override;
 
 private:
     void start();
@@ -161,8 +161,7 @@ void CertificateToPIVCardCommand::Private::startCertificateToPIVCard()
     Data data(&dp);
     const Error err = ctx->exportPublicKeys(certificate.primaryFingerprint(), data);
     if (err) {
-        error(i18nc("@info", "Exporting the certificate failed: %1", QString::fromUtf8(err.asString())),
-              i18nc("@title", "Error"));
+        error(i18nc("@info", "Exporting the certificate failed: %1", QString::fromUtf8(err.asString())));
         finished();
         return;
     }
@@ -177,7 +176,14 @@ void CertificateToPIVCardCommand::Private::startCertificateToPIVCard()
 
     const QByteArray command = QByteArrayLiteral("SCD WRITECERT ") + QByteArray::fromStdString(cardSlot);
     auto transaction = std::unique_ptr<AssuanTransaction>(new WriteCertAssuanTransaction(certificateData));
-    ReaderStatus::mutableInstance()->startTransaction(pivCard, command, q_func(), "certificateToPIVCardDone", std::move(transaction));
+    ReaderStatus::mutableInstance()->startTransaction(
+        pivCard,
+        command,
+        q_func(),
+        [this](const GpgME::Error &err) {
+            q->certificateToPIVCardDone(err);
+        },
+        std::move(transaction));
 }
 
 void CertificateToPIVCardCommand::Private::authenticate()
@@ -230,12 +236,9 @@ void CertificateToPIVCardCommand::certificateToPIVCardDone(const Error &err)
         }
 #endif
 
-        d->error(i18nc("@info", "Writing the certificate to the card failed: %1", QString::fromUtf8(err.asString())),
-                 i18nc("@title", "Error"));
+        d->error(i18nc("@info", "Writing the certificate to the card failed: %1", QString::fromUtf8(err.asString())));
     } else if (!err.isCanceled()) {
-        KMessageBox::information(d->parentWidgetOrView(),
-                                 i18nc("@info", "Writing the certificate to the card succeeded."),
-                                 i18nc("@title", "Success"));
+        d->success(i18nc("@info", "Writing the certificate to the card succeeded."));
         ReaderStatus::mutableInstance()->updateStatus();
     }
 
