@@ -17,8 +17,6 @@
 
 #include "commands/authenticatepivcardapplicationcommand.h"
 
-#include "dialogs/certificateselectiondialog.h"
-
 #include "smartcard/openpgpcard.h"
 #include "smartcard/pivcard.h"
 #include "smartcard/readerstatus.h"
@@ -44,7 +42,6 @@
 
 using namespace Kleo;
 using namespace Kleo::Commands;
-using namespace Kleo::Dialogs;
 using namespace Kleo::SmartCard;
 using namespace GpgME;
 
@@ -267,7 +264,9 @@ void KeyToCardCommand::Private::startKeyToOpenPGPCard() {
         .arg(QString::fromLatin1(subkey.keyGrip()), QString::fromStdString(serialNumber()))
         .arg(slot)
         .arg(timestamp);
-    ReaderStatus::mutableInstance()->startSimpleTransaction(pgpCard, cmd.toUtf8(), q_func(), "keyToOpenPGPCardDone");
+    ReaderStatus::mutableInstance()->startSimpleTransaction(pgpCard, cmd.toUtf8(), q_func(), [this](const GpgME::Error &err) {
+        q->keyToOpenPGPCardDone(err);
+    });
 }
 
 namespace {
@@ -389,7 +388,9 @@ void KeyToCardCommand::Private::startKeyToPIVCard()
     const QString cmd = QStringLiteral("KEYTOCARD --force %1 %2 %3")
         .arg(QString::fromLatin1(subkey.keyGrip()), QString::fromStdString(serialNumber()))
         .arg(QString::fromStdString(cardSlot));
-    ReaderStatus::mutableInstance()->startSimpleTransaction(pivCard, cmd.toUtf8(), q_func(), "keyToPIVCardDone");
+    ReaderStatus::mutableInstance()->startSimpleTransaction(pivCard, cmd.toUtf8(), q_func(), [this](const GpgME::Error &err) {
+        q->keyToPIVCardDone(err);
+    });
 }
 
 void KeyToCardCommand::Private::authenticate()
@@ -453,8 +454,7 @@ void KeyToCardCommand::keyToOpenPGPCardDone(const GpgME::Error &err)
 {
     if (err) {
         d->error(i18nc("@info",
-                       "Moving the key to the card failed: %1", QString::fromUtf8(err.asString())),
-                        i18nc("@title", "Error"));
+                       "Moving the key to the card failed: %1", QString::fromUtf8(err.asString())));
     } else if (!err.isCanceled()) {
         /* TODO DELETE_KEY is too strong, because it also deletes the stub
          * of the secret key. I could not find out how GnuPG does this. Question
@@ -468,8 +468,7 @@ void KeyToCardCommand::keyToOpenPGPCardDone(const GpgME::Error &err)
             ReaderStatus::mutableInstance()->startSimpleTransaction(card, cmd.toUtf8(), this, "deleteDone");
         }
         */
-        d->information(i18nc("@info", "Successfully copied the key to the card."),
-                       i18nc("@title", "Success"));
+        d->success(i18nc("@info", "Successfully copied the key to the card."));
         ReaderStatus::mutableInstance()->updateStatus();
     }
     d->finished();
@@ -489,11 +488,9 @@ void KeyToCardCommand::keyToPIVCardDone(const GpgME::Error &err)
 #endif
 
         d->error(i18nc("@info",
-                       "Copying the key pair to the card failed: %1", QString::fromUtf8(err.asString())),
-                        i18nc("@title", "Error"));
+                       "Copying the key pair to the card failed: %1", QString::fromUtf8(err.asString())));
     } else if (!err.isCanceled()) {
-        d->information(i18nc("@info", "Successfully copied the key pair to the card."),
-                       i18nc("@title", "Success"));
+        d->success(i18nc("@info", "Successfully copied the key pair to the card."));
         ReaderStatus::mutableInstance()->updateStatus();
     }
 
@@ -503,8 +500,7 @@ void KeyToCardCommand::keyToPIVCardDone(const GpgME::Error &err)
 void KeyToCardCommand::deleteDone(const GpgME::Error &err)
 {
     if (err) {
-        d->error(i18nc("@info", "Failed to delete the key: %1", QString::fromUtf8(err.asString())),
-                        i18nc("@title", "Error"));
+        d->error(i18nc("@info", "Failed to delete the key: %1", QString::fromUtf8(err.asString())));
     }
     d->finished();
 }
