@@ -9,13 +9,14 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_COMMANDS_KEYTOCARDCOMMAND_H__
-#define __KLEOPATRA_COMMANDS_KEYTOCARDCOMMAND_H__
+#pragma once
 
 #include <commands/cardcommand.h>
 
 #include <gpgme++/key.h>
 
+#include <memory>
+
 namespace Kleo
 {
 namespace SmartCard
@@ -57,4 +58,3 @@ private:
 }
 }
 
-#endif /* __KLEOPATRA_COMMANDS_KEYTOCARDCOMMAND_H__ */
