@@ -24,7 +24,9 @@ class RevokeCertificationCommand : public Command
     Q_OBJECT
 public:
     explicit RevokeCertificationCommand(QAbstractItemView *view, KeyListController *parent);
+    explicit RevokeCertificationCommand(const GpgME::Key &key);
     explicit RevokeCertificationCommand(const GpgME::UserID &uid);
+    explicit RevokeCertificationCommand(const std::vector<GpgME::UserID> &uids);
     explicit RevokeCertificationCommand(const GpgME::UserID::Signature &signature);
     ~RevokeCertificationCommand() override;
 
@@ -43,9 +45,6 @@ private:
     class Private;
     inline Private *d_func();
     inline const Private *d_func() const;
-    Q_PRIVATE_SLOT(d_func(), void slotResult(GpgME::Error))
-    Q_PRIVATE_SLOT(d_func(), void slotDialogAccepted())
-    Q_PRIVATE_SLOT(d_func(), void slotDialogRejected())
 };
 
 } // namespace Commands
