@@ -20,6 +20,8 @@
 #include <KSharedConfig>
 #include <KStandardGuiItem>
 
+#include <Libkleo/DocAction>
+
 #include <QDialogButtonBox>
 #include <QPushButton>
 
@@ -29,7 +31,6 @@ class GroupsConfigDialog::Private
     GroupsConfigDialog *const q;
 
     GroupsConfigPage *configPage = nullptr;
-    bool changed = false;
 
 public:
     Private(GroupsConfigDialog *qq)
@@ -78,14 +79,29 @@ GroupsConfigDialog::GroupsConfigDialog(QWidget *parent)
     KGuiItem::assign(resetButton, KStandardGuiItem::reset());
     resetButton->setEnabled(false);
 
+    const auto helpAction = new Kleo::DocAction(QIcon::fromTheme(QStringLiteral("help")),
+            i18n("Help"),
+            i18nc("Only available in German and English. Leave to English for other languages.",
+                  "handout_group-feature_gnupg_en.pdf"),
+            QStringLiteral("../share/doc/gnupg-vsd"));
+    if (helpAction->isEnabled()) {
+        auto helpButton = buttonBox()->button(QDialogButtonBox::Help);
+        if (helpButton) {
+            disconnect(helpButton, &QAbstractButton::clicked, nullptr, nullptr);
+            connect(helpButton, &QAbstractButton::clicked, helpAction, &QAction::trigger);
+            connect(helpButton, &QObject::destroyed, helpAction, &QObject::deleteLater);
+        }
+    } else {
+        delete helpAction;
+    }
+
     connect(buttonBox()->button(QDialogButtonBox::Reset), &QAbstractButton::clicked,
             this, &GroupsConfigDialog::updateWidgets);
 
-    connect(d->configPage, &GroupsConfigPage::changed, this, [this] (bool state) {
-        d->changed = state;
+    connect(d->configPage, &GroupsConfigPage::changed, this, [this]() {
         updateButtons();
         if (QPushButton *button = buttonBox()->button(QDialogButtonBox::Reset)) {
-            button->setEnabled(d->changed);
+            button->setEnabled(d->configPage->hasChanged());
         }
     });
 }
@@ -109,5 +125,5 @@ void GroupsConfigDialog::updateWidgets()
 
 bool GroupsConfigDialog::hasChanged()
 {
-    return d->changed;
+    return d->configPage->hasChanged();
 }
