@@ -32,7 +32,7 @@
 #include <utils/auditlog.h>
 #include <Libkleo/GnuPG>
 
-#include <kmime/kmime_header_parsing.h>
+#include <KMime/HeaderParsing>
 
 #include <gpgme++/error.h>
 #include <gpgme++/key.h>
@@ -48,6 +48,7 @@
 
 #include <QByteArray>
 #include <QDateTime>
+#include <QIODevice>
 #include <QStringList>
 #include <QTextDocument> // Qt::escape
 
@@ -125,7 +126,8 @@ static Mailbox mailbox(const UserID &uid)
 static std::vector<Mailbox> extractMailboxes(const Key &key)
 {
     std::vector<Mailbox> res;
-    Q_FOREACH (const UserID &id, key.userIDs()) {
+    const auto userIDs{key.userIDs()};
+    for (const UserID &id : userIDs) {
         const Mailbox mbox = mailbox(id);
         if (!mbox.addrSpec().isEmpty()) {
             res.push_back(mbox);
@@ -268,10 +270,10 @@ static QString formatSigningInformation(const Signature &sig)
     }
     text += i18n("With certificate:") + QStringLiteral("<br>") + renderKey(key);
 
-    if (Kleo::gpgComplianceP("de-vs")) {
+    if (Kleo::gnupgIsDeVsCompliant()) {
         text +=
             (QStringLiteral("<br/>")
-             + (IS_DE_VS(sig)
+             + (sig.isDeVs()
                 ? i18nc("%1 is a placeholder for the name of a compliance mode. E.g. NATO RESTRICTED compliant or VS-NfD compliant",
                         "The signature is %1", Formatting::deVsString())
                 : i18nc("%1 is a placeholder for the name of a compliance mode. E.g. NATO RESTRICTED compliant or VS-NfD compliant",
@@ -318,7 +320,8 @@ static bool IsGoodOrValid(const Signature &sig)
 
 static UserID findUserIDByMailbox(const Key &key, const Mailbox &mbox)
 {
-    Q_FOREACH (const UserID &id, key.userIDs())
+    const auto userIDs{key.userIDs()};
+    for (const UserID &id : userIDs)
         if (mailbox_equal(mailbox(id), mbox, Qt::CaseInsensitive)) {
             return id;
         }
@@ -525,21 +528,58 @@ static QString formatVerificationResultDetails(const VerificationResult &res, co
     return details;
 }
 
+static QString formatRecipientsDetails(const std::vector<Key> &knownRecipients, unsigned int numRecipients)
+{
+    if (numRecipients == 0) {
+        return {};
+    }
+
+    if (knownRecipients.empty()) {
+        return QLatin1String("<i>") +
+               i18np("One unknown recipient.", "%1 unknown recipients.", numRecipients) +
+               QLatin1String("</i>");
+    }
+
+    QString details = i18np("Recipient:", "Recipients:", numRecipients);
+
+    if (numRecipients == 1) {
+        details += QLatin1Char(' ') + renderKey(knownRecipients.front());
+    } else {
+        details += QLatin1String("<ul>");
+        for (const Key &key : knownRecipients) {
+            details += QLatin1String("<li>") + renderKey(key) + QLatin1String("</li>");
+        }
+        if (knownRecipients.size() < numRecipients) {
+            details += QLatin1String("<li><i>") +
+                       i18np("One unknown recipient", "%1 unknown recipients",
+                             numRecipients - knownRecipients.size()) +
+                       QLatin1String("</i></li>");
+        }
+        details += QLatin1String("</ul>");
+    }
+
+    return details;
+}
+
 static QString formatDecryptionResultDetails(const DecryptionResult &res, const std::vector<Key> &recipients,
                                              const QString &errorString, bool isSigned, const QPointer<Task> &task)
 {
-    QString details;
-
     if ((res.error().code() == GPG_ERR_EIO || res.error().code() == GPG_ERR_NO_DATA) && !errorString.isEmpty()) {
         return i18n("Input error: %1", errorString);
     }
 
-    if (Kleo::gpgComplianceP("de-vs")) {
-        details += ((IS_DE_VS(res)
+    if (res.isNull() || res.error() || res.error().isCanceled()) {
+        return formatRecipientsDetails(recipients, res.numRecipients());
+    }
+
+    QString details;
+
+    if (Kleo::gnupgIsDeVsCompliant()) {
+        details += ((res.isDeVs()
                      ? i18nc("%1 is a placeholder for the name of a compliance mode. E.g. NATO RESTRICTED compliant or VS-NfD compliant",
                              "The decryption is %1.", Formatting::deVsString())
                      : i18nc("%1 is a placeholder for the name of a compliance mode. E.g. NATO RESTRICTED compliant or VS-NfD compliant",
-                             "The decryption <b>is not</b> %1."), Formatting::deVsString())
+                             "The decryption <b>is not</b> %1.", Formatting::deVsString()))
                     + QStringLiteral("<br/>"));
     }
 
@@ -555,15 +595,9 @@ static QString formatDecryptionResultDetails(const DecryptionResult &res, const
         }
     }
 
-    if (res.isNull() || !res.error() || res.error().isCanceled()) {
-        if (!isSigned) {
-            return details + i18n("<b>Note:</b> You cannot be sure who encrypted this message as it is not signed.");
-        }
-        return details;
-    }
-
-    if (recipients.empty() && res.numRecipients() > 0) {
-        return details + QLatin1String("<i>") + i18np("One unknown recipient.", "%1 unknown recipients.", res.numRecipients()) + QLatin1String("</i>");
+    if (!isSigned) {
+        details += i18n("<b>Note:</b> You cannot be sure who encrypted this message as it is not signed.")
+                   + QLatin1String("<br/>");
     }
 
     if (res.isLegacyCipherNoMDC()) {
@@ -576,22 +610,7 @@ static QString formatDecryptionResultDetails(const DecryptionResult &res, const
                    QStringLiteral("<br/><br/>");
     }
 
-    if (!recipients.empty()) {
-        details += i18np("Recipient:", "Recipients:", res.numRecipients());
-        if (res.numRecipients() == 1) {
-            return details + QLatin1Char(' ') + renderKey(recipients.front());
-        }
-
-        details += QLatin1String("<ul>");
-        for (const Key &key : recipients) {
-            details += QLatin1String("<li>") + renderKey(key) + QLatin1String("</li>");
-        }
-        if (recipients.size() < res.numRecipients())
-            details += QLatin1String("<li><i>") + i18np("One unknown recipient", "%1 unknown recipients",
-                       res.numRecipients() - recipients.size()) + QLatin1String("</i></li>");
-
-        details += QLatin1String("</ul>");
-    }
+    details += formatRecipientsDetails(recipients, res.numRecipients());
 
     return details;
 }
@@ -628,6 +647,7 @@ public:
             const VerificationResult &vr,
             const DecryptionResult &dr,
             const QByteArray &stuff,
+            const QString &fileName,
             int errCode,
             const QString &errString,
             const QString &input,
@@ -641,6 +661,7 @@ public:
         m_verificationResult(vr),
         m_decryptionResult(dr),
         m_stuff(stuff),
+        m_fileName(fileName),
         m_error(errCode),
         m_errorString(errString),
         m_inputLabel(input),
@@ -674,6 +695,7 @@ public:
     VerificationResult m_verificationResult;
     DecryptionResult m_decryptionResult;
     QByteArray m_stuff;
+    QString m_fileName;
     int m_error;
     QString m_errorString;
     QString m_inputLabel;
@@ -695,6 +717,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptResul
             VerificationResult(),
             dr,
             plaintext,
+            {},
             0,
             QString(),
             inputLabel(),
@@ -711,6 +734,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptResul
             VerificationResult(),
             DecryptionResult(err),
             QByteArray(),
+            {},
             err.code(),
             what,
             inputLabel(),
@@ -720,7 +744,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptResul
             informativeSender()));
 }
 
-std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptVerifyResult(const DecryptionResult &dr, const VerificationResult &vr, const QByteArray &plaintext, const AuditLog &auditLog)
+std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptVerifyResult(const DecryptionResult &dr, const VerificationResult &vr, const QByteArray &plaintext, const QString &fileName, const AuditLog &auditLog)
 {
     int err = dr.error() ? dr.error().code() : vr.error().code();
     return std::shared_ptr<DecryptVerifyResult>(new DecryptVerifyResult(
@@ -728,6 +752,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptVerif
             vr,
             dr,
             plaintext,
+            fileName,
             err,
             QString(),
             inputLabel(),
@@ -744,6 +769,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromDecryptVerif
             VerificationResult(),
             DecryptionResult(err),
             QByteArray(),
+            {},
             err.code(),
             details,
             inputLabel(),
@@ -760,6 +786,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyOpaque
             vr,
             DecryptionResult(),
             plaintext,
+            {},
             0,
             QString(),
             inputLabel(),
@@ -775,6 +802,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyOpaque
             VerificationResult(err),
             DecryptionResult(),
             QByteArray(),
+            {},
             err.code(),
             details,
             inputLabel(),
@@ -791,6 +819,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyDetach
             vr,
             DecryptionResult(),
             QByteArray(),
+            {},
             0,
             QString(),
             inputLabel(),
@@ -806,6 +835,7 @@ std::shared_ptr<DecryptVerifyResult> AbstractDecryptVerifyTask::fromVerifyDetach
             VerificationResult(err),
             DecryptionResult(),
             QByteArray(),
+            {},
             err.code(),
             details,
             inputLabel(),
@@ -819,6 +849,7 @@ DecryptVerifyResult::DecryptVerifyResult(DecryptVerifyOperation type,
         const VerificationResult &vr,
         const DecryptionResult &dr,
         const QByteArray &stuff,
+        const QString &fileName,
         int errCode,
         const QString &errString,
         const QString &inputLabel,
@@ -826,7 +857,7 @@ DecryptVerifyResult::DecryptVerifyResult(DecryptVerifyOperation type,
         const AuditLog &auditLog,
         Task *parentTask,
         const Mailbox &informativeSender)
-    : Task::Result(), d(new Private(type, vr, dr, stuff, errCode, errString, inputLabel, outputLabel, auditLog, parentTask, informativeSender, this))
+    : Task::Result(), d(new Private(type, vr, dr, stuff, fileName, errCode, errString, inputLabel, outputLabel, auditLog, parentTask, informativeSender, this))
 {
 }
 
@@ -906,6 +937,11 @@ GpgME::DecryptionResult DecryptVerifyResult::decryptionResult() const
     return d->m_decryptionResult;
 }
 
+QString DecryptVerifyResult::fileName() const
+{
+    return d->m_fileName;
+}
+
 class AbstractDecryptVerifyTask::Private
 {
 public:
@@ -992,7 +1028,7 @@ void DecryptVerifyTask::Private::slotResult(const DecryptionResult &dr, const Ve
         return;
     }
 
-    emitResult(q->fromDecryptVerifyResult(dr, vr, plainText, auditLog));
+    emitResult(q->fromDecryptVerifyResult(dr, vr, plainText, m_output->fileName(), auditLog));
 }
 
 DecryptVerifyTask::DecryptVerifyTask(QObject *parent) : AbstractDecryptVerifyTask(parent), d(new Private(this))
